.. _settings:

Settings
========

Below is a list of all the position settings

.. _setting_content_overlap_count:

==============================
POSITION_CONTENT_OVERLAP_COUNT
==============================

The number of objects to keep after the position has added more items then 
its position.count specified. 

**Default** - 2.

.. _setting_combine_string:

=======================
POSITION_COMBINE_STRING
=======================

A url safe string used to combine position name prefix and suffix. This is 
also used to build template paths.

**Default** - __ (2 under scores)


 
